==> Paws-0.01.tar.gz: Paws-0.01/lib/Paws/Route53/CreateHealthCheckResponse.pm <==

package Paws::Route53::CreateHealthCheckResponse {
  use Moose;
  with 'Paws::API::ResultParser';
  has HealthCheck => (is => 'ro', isa => 'Paws::Route53::HealthCheck', required => 1);
  has Location => (is => 'ro', isa => 'Str', required => 1);

}
1;

### main pod documentation begin ###

=head1 NAME

Paws::Route53:: - Arguments for method  on Paws::Route53

=head1 DESCRIPTION

This class represents the parameters used for calling the method  on the 
Amazon Route 53 service. Use the attributes of this class
as arguments to method .

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to .

As an example:

  $service_obj->(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> HealthCheck => Paws::Route53::HealthCheck

  

A complex type that contains identifying information about the health
check.










=head2 B<REQUIRED> Location => Str

  

The unique URL representing the new health check.












=head1 SEE ALSO

This class forms part of L<Paws>, and documents parameters for  in Paws::Route53

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.06.tar.gz: Paws-0.06/lib/Paws/Route53/CreateHealthCheckResponse.pm <==

package Paws::Route53::CreateHealthCheckResponse {
  use Moose;
  with 'Paws::API::ResultParser';
  has HealthCheck => (is => 'ro', isa => 'Paws::Route53::HealthCheck', required => 1);
  has Location => (is => 'ro', isa => 'Str', required => 1);

}
1;

### main pod documentation begin ###

=head1 NAME

Paws::Route53:: - Arguments for method  on Paws::Route53

=head1 DESCRIPTION

This class represents the parameters used for calling the method  on the 
Amazon Route 53 service. Use the attributes of this class
as arguments to method .

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to .

As an example:

  $service_obj->(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> HealthCheck => Paws::Route53::HealthCheck

  

A complex type that contains identifying information about the health
check.










=head2 B<REQUIRED> Location => Str

  

The unique URL representing the new health check.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method  in L<Paws::Route53>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
